Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
jinja2_async_environment/bccache.py | 57 | 0 | 3 | 100%
jinja2_async_environment/caching/manager.py | 136 | 91 | 5 | 33%
jinja2_async_environment/caching/strategies.py | 220 | 176 | 0 | 20%
jinja2_async_environment/caching/typed.py | 124 | 69 | 0 | 44%
jinja2_async_environment/caching/unified.py | 59 | 42 | 6 | 29%
jinja2_async_environment/compiler.py | 9 | 0 | 0 | 100%
jinja2_async_environment/compiler_modules/cache.py | 18 | 9 | 0 | 50%
jinja2_async_environment/compiler_modules/codegen.py | 512 | 84 | 12 | 84%
jinja2_async_environment/compiler_modules/dependencies.py | 40 | 18 | 0 | 55%
jinja2_async_environment/compiler_modules/frame.py | 65 | 0 | 3 | 100%
jinja2_async_environment/compiler_modules/loops.py | 27 | 4 | 0 | 85%
jinja2_async_environment/compiler_modules/patterns.py | 44 | 0 | 1 | 100%
jinja2_async_environment/compiler_old.py | 683 | 683 | 14 | 0%
jinja2_async_environment/environment.py | 226 | 17 | 5 | 92%
jinja2_async_environment/loaders/base.py | 97 | 23 | 27 | 76%
jinja2_async_environment/loaders/choice.py | 52 | 12 | 0 | 77%
jinja2_async_environment/loaders/dict.py | 47 | 8 | 0 | 83%
jinja2_async_environment/loaders/filesystem.py | 83 | 31 | 0 | 63%
jinja2_async_environment/loaders/function.py | 50 | 10 | 0 | 80%
jinja2_async_environment/loaders/package.py | 182 | 59 | 9 | 68%
jinja2_async_environment/loaders_old.py | 462 | 338 | 18 | 27%
jinja2_async_environment/testing/context.py | 41 | 41 | 1 | 0%
jinja2_async_environment/testing/fixtures.py | 53 | 53 | 3 | 0%
Total | 3287 | 1768 | 107 | 46%

No items found using the specified filter.